function [F, J] = finite_difference(fun, x, param)
% Calculates the Jacobian of function "fun" in "x" using finite differences
% F: the function value in "x"
% J: Jacobian of "fun" in "x"

% Definining the step length
h = sqrt(eps);

F = fun(x, param);

nx = length(x);

J = zeros(length(F), nx);

% In each loop we obtain one column of the Jacobian
% This is the seed
p = zeros(nx, 1);
for k = 1 : nx
    p(k) = 1 * h;
    J(:, k) = (fun(x + p,param)  - F)/h;
    p(k) = 0;
end
